==> vajram-java-sdk-9.0.0-20250418.225804-5-sources.jar: com/flipkart/krystal/vajram/facets/resolution/MandatoryAsIsResolverStage.java <==
package com.flipkart.krystal.vajram.facets.resolution;

import com.flipkart.krystal.data.FacetValue.SingleFacetValue;
import com.flipkart.krystal.data.Request;
import com.flipkart.krystal.vajram.exception.MandatoryFacetMissingException;
import com.flipkart.krystal.vajram.facets.specs.InputMirrorSpec;
import com.flipkart.krystal.vajram.facets.specs.MandatorySingleValueFacetSpec;
import java.util.ArrayList;
import java.util.List;
import java.util.function.Predicate;
import java.util.function.Supplier;

public final class MandatoryAsIsResolverStage<T, CV extends Request, DV extends Request> {
  private final InputMirrorSpec<T, DV> targetInput;
  private final MandatorySingleValueFacetSpec<T, CV> sourceFacet;
  private final List<SkipPredicate> skipConditions = new ArrayList<>();

  MandatoryAsIsResolverStage(
      InputMirrorSpec<T, DV> targetInput, MandatorySingleValueFacetSpec<T, CV> sourceFacet) {
    this.targetInput = targetInput;
    this.sourceFacet = sourceFacet;
  }

  @SuppressWarnings("unchecked")
  public MandatoryAsIsResolverStage<T, CV, DV> skipIf(Predicate<T> whenToSkip, String reason) {
    this.skipConditions.add(
        new SkipPredicate(
            reason,
            facetValue ->
                whenToSkip.test(
                    ((SingleFacetValue<T>) facetValue)
                        .singleValue()
                        .valueOpt()
                        .orElseThrow(mandatoryFacetMissingException()))));
    return this;
  }

  @SuppressWarnings("unchecked")
  public SimpleInputResolverSpec<T, CV, DV> asResolver() {
    return new SimpleInputResolverSpec<>(
        targetInput,
        sourceFacet,
        skipConditions,
        new Transformer.One2One(
            t -> t.singleValue().valueOpt().orElseThrow(mandatoryFacetMissingException())));
  }

  private Supplier<MandatoryFacetMissingException> mandatoryFacetMissingException() {
    return () ->
        new MandatoryFacetMissingException(sourceFacet.ofVajramID().vajramId(), sourceFacet.name());
  }
}

==> vajram-java-sdk-9.0.0-20250424.033432-11-sources.jar: com/flipkart/krystal/vajram/facets/resolution/MandatoryAsIsResolverStage.java <==
package com.flipkart.krystal.vajram.facets.resolution;

import com.flipkart.krystal.data.FacetValue.SingleFacetValue;
import com.flipkart.krystal.data.Request;
import com.flipkart.krystal.vajram.exception.MandatoryFacetMissingException;
import com.flipkart.krystal.vajram.facets.specs.InputMirrorSpec;
import com.flipkart.krystal.vajram.facets.specs.MandatorySingleValueFacetSpec;
import java.util.ArrayList;
import java.util.List;
import java.util.function.Predicate;
import java.util.function.Supplier;

public final class MandatoryAsIsResolverStage<T, CV extends Request, DV extends Request> {
  private final InputMirrorSpec<T, DV> targetInput;
  private final MandatorySingleValueFacetSpec<T, CV> sourceFacet;
  private final List<SkipPredicate> skipConditions = new ArrayList<>();

  MandatoryAsIsResolverStage(
      InputMirrorSpec<T, DV> targetInput, MandatorySingleValueFacetSpec<T, CV> sourceFacet) {
    this.targetInput = targetInput;
    this.sourceFacet = sourceFacet;
  }

  @SuppressWarnings("unchecked")
  public MandatoryAsIsResolverStage<T, CV, DV> skipIf(Predicate<T> whenToSkip, String reason) {
    this.skipConditions.add(
        new SkipPredicate(
            reason,
            facetValue ->
                whenToSkip.test(
                    ((SingleFacetValue<T>) facetValue)
                        .singleValue()
                        .valueOpt()
                        .orElseThrow(this::mandatoryFacetMissingException))));
    return this;
  }

  @SuppressWarnings("unchecked")
  public SimpleInputResolverSpec<T, CV, DV> asResolver() {
    return new SimpleInputResolverSpec<>(
        targetInput,
        sourceFacet,
        skipConditions,
        new Transformer.One2One(
            t -> t.singleValue().valueOpt().orElseThrow(this::mandatoryFacetMissingException)));
  }

  private MandatoryFacetMissingException mandatoryFacetMissingException() {
    return new MandatoryFacetMissingException(
        sourceFacet.ofVajramID().vajramId(), sourceFacet.name());
  }
}
